Welcome to sar_coloc's documentation!
======================================

Reference
.........

* :doc:`api`

Get in touch
------------

Last documentation build: |today|

- Report bugs, suggest features or view the source code `on github`_.

.. _on github: https://github.com/umr-lops/coloc_sat

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Reference

   api


.. toctree::
   :maxdepth: 3
   :caption: Contents:

   README
   installation
   usage
   program_functionality_documentation
   development
   improvements
   authors
   contributing


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
